import { type GraphqlMiddlewareQueryName, type KeysOf, type PickFrom } from './../helpers/composables.js';
import type { FetchOptions } from 'ofetch';
import { type Ref } from 'vue';
import { type GraphqlClientContext } from '#graphql-middleware-client-options';
import type { GraphqlMiddlewareQuery } from '#nuxt-graphql-middleware/generated-types';
import type { GraphqlResponse } from '#graphql-middleware-server-options-build';
import type { RequestCacheOptions } from '#graphql-middleware/types';
import type { AsyncData, AsyncDataOptions, NuxtError } from '#app';
import type { DefaultAsyncDataValue } from 'nuxt/app/defaults';
type AsyncGraphqlQueryOptions<FetchOptions, ResT, DataT = ResT, PickKeys extends KeysOf<DataT> = KeysOf<DataT>, DefaultT = DefaultAsyncDataValue> = AsyncDataOptions<ResT, DataT, PickKeys, DefaultT> & {
    /**
     * Control how the GraphQL response can be cached.
     */
    graphqlCaching?: RequestCacheOptions;
    /**
     * Options for the fetch call to the GraphQL middleware endpoint.
     */
    fetchOptions?: FetchOptions;
    /**
     * Additional client context.
     *
     * These values override the values defined globally in defineGraphqlClientOptions().
     */
    clientContext?: Partial<GraphqlClientContext>;
};
export declare function useAsyncGraphqlQuery<Name extends GraphqlMiddlewareQueryName, VarType extends GraphqlMiddlewareQuery[Name][0], VarsOptional extends GraphqlMiddlewareQuery[Name][1], ResT extends GraphqlResponse<GraphqlMiddlewareQuery[Name][2]>, FetchO extends FetchOptions<'json'>, NuxtErrorDataT = unknown, DataT = ResT, DefaultT = undefined, PickKeys extends KeysOf<DataT> = KeysOf<DataT>>(name: Name, ...args: VarsOptional extends true ? [
    (undefined | null | Record<string, never> | VarType | Ref<VarType>)?,
    AsyncGraphqlQueryOptions<FetchO, ResT, DataT, PickKeys, DefaultT>?
] : [
    VarType | Ref<VarType>,
    (undefined | null | AsyncGraphqlQueryOptions<FetchO, ResT, DataT, PickKeys, DefaultT>)?
]): AsyncData<PickFrom<DataT, PickKeys> | DefaultT, (NuxtErrorDataT extends Error | NuxtError ? NuxtErrorDataT : NuxtError<NuxtErrorDataT>) | undefined>;
export declare function useAsyncGraphqlQuery<Name extends GraphqlMiddlewareQueryName, VarType extends GraphqlMiddlewareQuery[Name][0], VarsOptional extends GraphqlMiddlewareQuery[Name][1], ResT extends GraphqlResponse<GraphqlMiddlewareQuery[Name][2]>, FetchO extends FetchOptions<'json'>, NuxtErrorDataT = unknown, DataT = ResT, DefaultT = DataT, PickKeys extends KeysOf<DataT> = KeysOf<DataT>>(name: Name, ...args: VarsOptional extends true ? [
    (undefined | null | Record<string, never> | VarType | Ref<VarType>)?,
    AsyncGraphqlQueryOptions<FetchO, ResT, DataT, PickKeys, DefaultT>?
] : [
    VarType | Ref<VarType>,
    (undefined | null | AsyncGraphqlQueryOptions<FetchO, ResT, DataT, PickKeys, DefaultT>)?
]): AsyncData<PickFrom<DataT, PickKeys> | DefaultT, (NuxtErrorDataT extends Error | NuxtError ? NuxtErrorDataT : NuxtError<NuxtErrorDataT>) | undefined>;
export {};
