import {
  encodeContext
} from "./../helpers/composables.js";
import { isRef, unref } from "vue";
import { buildRequestParams } from "./../helpers/index.js";
import { performRequest } from "./nuxtApp.js";
import {
  clientOptions
} from "#graphql-middleware-client-options";
import { useAsyncData, useAppConfig, useNuxtApp } from "#imports";
import { hash } from "ohash";
export function useAsyncGraphqlQuery(name, ...args) {
  const variables = args[0];
  const asyncDataOptions = args[1] || {};
  const fetchOptions = asyncDataOptions.fetchOptions;
  const key = `graphql:${name}:${hash(unref(variables))}`;
  const config = useAppConfig();
  const app = useNuxtApp();
  if (import.meta.client) {
    if (variables && isRef(variables)) {
      if (!asyncDataOptions.watch) {
        asyncDataOptions.watch = [];
      }
      asyncDataOptions.watch.push(variables);
    }
    if (asyncDataOptions.graphqlCaching?.client && !asyncDataOptions.getCachedData) {
      asyncDataOptions.getCachedData = function(key2) {
        if (!app.isHydrating && !config.graphqlMiddleware.clientCacheEnabled) {
          return;
        }
        return app.payload.data[key2];
      };
    }
  }
  return useAsyncData(
    key,
    () => {
      const globalClientContext = clientOptions.buildClientContext ? clientOptions.buildClientContext() : {};
      return performRequest(
        "query",
        name,
        "get",
        {
          ...fetchOptions,
          params: {
            ...fetchOptions?.params || {},
            ...buildRequestParams(unref(variables)),
            ...encodeContext({
              ...globalClientContext,
              ...asyncDataOptions.clientContext || {}
            })
          }
        },
        asyncDataOptions.graphqlCaching
      );
    },
    asyncDataOptions
  );
}
