import { defineEventHandler, getQuery, readBody } from "h3";
import {
  queryParamToVariables,
  getEndpoint,
  getFetchOptions,
  validateRequest,
  onServerResponse,
  onServerError,
  extractRequestContext
} from "./helpers/index.js";
import { GraphqlMiddlewareOperation } from "./../settings/index.js";
import { operations } from "#graphql-documents";
import { serverOptions } from "#graphql-middleware-server-options-build";
import { useRuntimeConfig } from "#imports";
export default defineEventHandler(async (event) => {
  const method = event.method;
  const operation = event.context?.params?.operation;
  const operationName = event.context?.params?.name;
  validateRequest(method, operation, operationName, operations);
  const operationDocument = operations[operation][operationName];
  const queryParams = getQuery(event);
  const context = extractRequestContext(queryParams);
  const variables = operation === GraphqlMiddlewareOperation.Query ? queryParamToVariables(queryParams) : await readBody(event);
  if (serverOptions.doGraphqlRequest) {
    return serverOptions.doGraphqlRequest({
      event,
      operation,
      operationName,
      operationDocument,
      variables,
      context
    });
  }
  const runtimeConfig = useRuntimeConfig().graphqlMiddleware;
  const endpoint = await getEndpoint(
    runtimeConfig,
    serverOptions,
    event,
    operation,
    operationName,
    context
  );
  const fetchOptions = await getFetchOptions(
    serverOptions,
    event,
    operation,
    operationName,
    context
  );
  return $fetch.raw(endpoint, {
    // @todo: Remove any once https://github.com/unjs/nitro/pull/883 is released.
    method: "POST",
    body: {
      query: operationDocument,
      variables,
      operationName
    },
    ...fetchOptions
  }).then((response) => {
    return onServerResponse(
      serverOptions,
      event,
      response,
      operation,
      operationName,
      context
    );
  }).catch((error) => {
    return onServerError(
      serverOptions,
      event,
      error,
      operation,
      operationName,
      context
    );
  });
});
